<?php
// $Id: template.inc,v 3.0.6.9 2008/06/21 00:00:00 hass Exp $

/**
 * "Yet Another Multicolumn Layout" for Drupal
 *
 * (en) Central template for global theme functions
 * (de) Zentrales Template für globale Theme-Funktionen
 *
 * @copyright       Copyright 2006-2008, Alexander Hass
 * @license         http://www.yaml-fuer-drupal.de/en/terms-of-use
 * @link            http://www.yaml-for-drupal.com
 * @package         yaml-for-drupal
 * @version         5.x-3.0.6.9
 * @lastmodified    2008-06-21
 */

/**
 * This snippet changes primary links layout
 */
function phptemplate_links_primary($links) {
  $output = '';
  $count = 1;
  if (count($links)) {
    $output .= '<ul>';
    foreach ($links as $link) {
      $output .= '<li';
      if (((drupal_get_normal_path($link['href']) == $_GET['q']) || (drupal_is_front_page() && $link['href'] == '<front>')) && $count == 1) {
        $output .= ' id="current"';
        // Prevent duplication of id for html validity
        $count++;
      }
      $output .= '>'. l($link['title'], $link['href'], $link['attributes'], $link['query'], $link['fragment']) ."</li>\n";
    }
    $output .= '</ul>';
  }
  return $output;
}

/**
 * This snippet changes seconday links layout
 */
function phptemplate_links_secondary($links, $delimiter = ' | ', $leftcab = '', $rightcab = '') {
  // Display the left cap of the 'button bar'
  $output  = '';
  $output .= $leftcab;
  $link_count = count($links);
  $current = 1;
  foreach ($links as $link) {
      $output .= l($link['title'], $link['href'], $link['attributes'], $link['query'], $link['fragment']);
      // Only print the delimiter if not the last link
      if ($current < $link_count) {
        $output .= $delimiter;
      }
      $current++;
  }
  // Display the right cap of the 'button bar'
  $output .= $rightcab;

  return $output;
}

/**
 * This snippet changes default menu layout
 */
function phptemplate_menu_tree($pid = 1) {
  if ($tree = menu_tree($pid)) {
    $output .= '<ul class="menu">';
    $output .= $tree;
    $output .= '</ul>';
    return $output;
  }
}
function phptemplate_menu_item($mid, $children = '', $leaf = TRUE) {
  // return '<li class="'. ($leaf ? 'leaf' : ($children ? 'expanded' : 'collapsed')) . (menu_in_active_trail($mid) ? ' active' : '') .'">'. menu_item_link($mid) . $children ."</li>\n";
  return '<li class="'. ($leaf ? 'leaf' : ($children ? 'expanded' : 'collapsed')) .'">'. menu_item_link($mid) . $children ."</li>\n";
}

/**
* Catch the theme_profile_profile function, and redirect through the template api
*/
/*
function phptemplate_user_profile($user, $fields = array()) {
  // Pass to phptemplate, including translating the parameters to an associative array. The element names are the names that the variables
  // will be assigned within your template.
  // potential need for other code to extract field info
  return _phptemplate_callback('user-profile', array('user' => $user, 'fields' => $fields));
}
*/

/**
 * TODO: Customize the search form for breadcrumb position
 */
// jQuery Example
// drupal_add_js("$("#SearchText").focus(function() { if (this.value == "Search...") this.value = ""; });", 'inline', 'header', FALSE);
/*
function phptemplate_search_theme_form($form) {
  $output .= '<input type="text" maxlength="128" name="search_theme_form_keys" id="edit-search_theme_form_keys" value="'.t('Search...').'" title="'.t('Enter the terms you wish to search for.').'" class="form-text" onblur="if(this.value==\'\') this.value=\''.t('Search...').'\';" onfocus="if(this.value==\''.t('Search...').'\') this.value=\'\';" />';
  $output .= '<input type="submit" name="op" value="'.t('Search...').'" style="display: none;" />';
  $output .= '<input type="hidden" name="form_id" id="edit-search-theme-form" value="search_theme_form" />';
  $output .= '<input type="hidden" name="form_token" id="a-unique-id" value="'.drupal_get_token('search_theme_form').'" />';
  return $output;
}
*/

/**
 * Returns the rendered local tasks. The default implementation renders
 * them as tabs.
 *
 * @ingroup themeable
 */
/*
function phptemplate_menu_local_tasks() {
  $output = '';

  if ($primary = menu_primary_local_tasks()) {
    $output .= "<ul class=\"tabs primary\">\n". $primary ."</ul>\n";
  }

  return $output;
} */

/**
 * This snippet will add module styles if module is installed and active.
 * TODO: Add CSS only if page requires file.
 */
function _yaml_add_css_modules($base_theme_directory = '') {

  // Add module styles if modules exists
  // The unique modules directory name should be used as CSS filename.
  if (module_exists('menu_block_split')) {
    drupal_add_css($base_theme_directory .'/css/modules/menu_block_split.css', 'theme');
  }
  if (module_exists('jrating')) {
    drupal_add_css($base_theme_directory .'/css/modules/jrating.css', 'theme');
  }
  if (module_exists('service_links')) {
    drupal_add_css($base_theme_directory .'/css/modules/service_links.css', 'theme');
  }
  if (module_exists('site_map') && arg(0) == 'sitemap') {
    drupal_add_css($base_theme_directory .'/css/modules/site_map.css', 'theme');
  }
  if (module_exists('project') && arg(0) == 'project') {
    drupal_add_css($base_theme_directory .'/css/modules/project.css', 'theme');
  }

  // Add non Drupal modules here.
  // To avoid naming conflicts an underscore should be added as prefix
  // to CSS filenames of modules not contributed on drupal.org.
  // if (foo == bar) {
  //   drupal_add_css($base_theme_directory .'/css/modules/_example.css', 'theme');
  // }

}

/**
 * Add backlinks required by license to footer.
 *
 * This back linking maybe only removed, if you possess
 * a YAML Framework and YAML for Drupal license.
 *
 * For more information read the "YAML" and "YAML for Drupal" license, please.
 *
 * Licenses:
 * YAML - http://www.yaml.de
 * YAML for Drupal - http://www.yaml-for-drupal.com
 */
function phptemplate_footer_message($output = '', $delimiter = ' | ', $leftcab = '', $rightcab = '') {

  $footer_items = array();

  // If you don't like the validation links, simply uncheck on theme settings page.
  if (theme_get_setting('yaml_display_link_validation_xhtml') !== 0) {
    $footer_items[] = t('<a href="http://validator.w3.org/check/referer" title="Validate XHTML">XHTML</a>');
  }

  if (theme_get_setting('yaml_display_link_validation_css') !== 0) {
    $footer_items[] = t('<a href="http://jigsaw.w3.org/css-validator/check/referer" title="Validate CSS">CSS</a>');
  }

  /**
   * GERMAN:
   * Diese Rückverlinkung darf nur entfernt werden,
   * wenn Sie eine YAML-Framework Lizenz besitzen.
   * :: Lizenzbedingungen: http://www.yaml.de
   *
   * ENGLISH:
   * This back linking maybe only removed,
   * if you possess a YAML Framework license.
   * :: License conditions: http://www.yaml.de
   */
  if (theme_get_setting('yaml_display_link_license_yaml') !== 0) {
    $footer_items[] = t('Layout based on <a href="http://www.yaml.de/">YAML</a>');
  }

  /**
   * GERMAN:
   * Diese Rückverlinkung darf nur entfernt werden,
   * wenn Sie eine YAML für Drupal Lizenz besitzen.
   * :: Lizenzbedingungen: http://www.yaml-fuer-drupal.de
   *
   * ENGLISH:
   * This back linking maybe only removed,
   * if you have possess a YAML for Drupal license.
   * :: License conditions: http://www.yaml-for-drupal.com
   */
  if (theme_get_setting('yaml_display_link_license_yamlfd') !== 0) {
    $footer_items[] = t('<a href="http://www.yaml-fuer-drupal.de/" title="YAML for Drupal Theme">YAML for Drupal</a> Theme');
  }

  // Build footer and links if exists
  $footer_links_output = '';
  if (!empty($footer_items)) {
    $footer_links_output = implode($delimiter, $footer_items);
  }

  $footer_output = '';
  if (trim($output) && !empty($footer_links_output)) {
    $footer_output = $output .'<br />'. $leftcab . $footer_links_output . $rightcab;
  }
  elseif (!trim($output) && !empty($footer_links_output)) {
    $footer_output = $leftcab . $footer_links_output . $rightcab;
  }
  else {
    $footer_output = $output;
  }

  // Return footer
  return $footer_output;
}

/**
 * We will detect if client is Internet Explorer. Then we are able to add
 * the XML prolog for XHTML Standard Compliance Mode for other browsers.
 *
 * Today IE is the only known software we need to workaround and therefor we
 * only detect IE browser and suppose all other browsers render correctly with
 * XML prolog.
 */
function _browser_xml_prolog_compliant() {
  $ua = $_SERVER['HTTP_USER_AGENT'];

  if (eregi('msie', $ua) && !eregi('opera', $ua)) {
    // This is not a Opera pose as IE
    $clientdata = explode(' ', stristr($ua, 'msie'));
    $client['version'] = $clientdata[1];

    if ($client['version'] >= 7) {
      // IE >= 7.0: http://blogs.msdn.com/ie/archive/2005/09/15/467901.aspx
      $xml_prolog_compliant = TRUE;
    }
    else {
      // IE <= 6.0
      $xml_prolog_compliant = FALSE;
    }
  }
  else {
    // all other browsers
    $xml_prolog_compliant = TRUE;
  }

  return $xml_prolog_compliant;
}


function _yaml_get_css_themesettings($column_order = '') {
  $styles = '';
  $yaml_layout_page_width_col1 = theme_get_setting('yaml_layout_page_width_col1');
  $yaml_layout_page_width_col3 = theme_get_setting('yaml_layout_page_width_col3');

  $settings = '';
  switch ($column_order) {
    case '132':
      // 3 column standard layout
      if ($yaml_layout_page_width_col1 != '25%' || $yaml_layout_page_width_col3 != '25%') {
        if (!empty($yaml_layout_page_width_col1)) {
          $settings .= '#col1 { width: '. $yaml_layout_page_width_col1 .' }';
        }
        if (!empty($yaml_layout_page_width_col3)) {
          $settings .= '#col2 { width: '. $yaml_layout_page_width_col3 .' }';
        }
        if (!empty($yaml_layout_page_width_col1) && !empty($yaml_layout_page_width_col3)) {
          $settings .= '#col3 { margin: 0 '. $yaml_layout_page_width_col3 .' 0 '. $yaml_layout_page_width_col1 .' }';
        }
      }
      break;

    case '13':
      // 2 column 12 layout
      if ($yaml_layout_page_width_col1 != '25%') {
        if (!empty($yaml_layout_page_width_col1)) {
          $settings .= '#col1 { width: '. $yaml_layout_page_width_col1 .' }';
        }
        if (!empty($yaml_layout_page_width_col1) && !empty($yaml_layout_page_width_col3)) {
          $settings .= '#col3 { width: '. $yaml_layout_page_width_col3 .'; margin: 0 0 0 '. $yaml_layout_page_width_col1 .' }';
        }
      }
      break;

    case '31':
      // 2 columns 31 layout
      if ($yaml_layout_page_width_col1 != '25%') {
        if (!empty($yaml_layout_page_width_col1)) {
          $settings .= '#col1 { width: '. $yaml_layout_page_width_col1 .' }';
        }
        if (!empty($yaml_layout_page_width_col1) && !empty($yaml_layout_page_width_col3)) {
          $settings .= '#col3 { width: '. $yaml_layout_page_width_col3 .'; margin: 0 '. $yaml_layout_page_width_col1 .' 0 0 }';
        }
      }
      break;
  }
  
  if (!empty($settings)) {
    $styles .= '<style type="text/css">'. $settings .'</style>' . "\n";
  }  
  
  // Page settings
  $yaml_layout_page_width_min = theme_get_setting('yaml_layout_page_width_min');
  $yaml_layout_page_width_max = theme_get_setting('yaml_layout_page_width_max');
  $yaml_layout_page_align = theme_get_setting('yaml_layout_page_align');
  switch ($yaml_layout_page_align) {
    case 'left':
      $styles .= '<style type="text/css">#page_margins { margin-right: auto; margin-left: 0; width: '.theme_get_setting('yaml_layout_page_width') .'; min-width: '. check_plain($yaml_layout_page_width_min) .'; max-width: '. check_plain($yaml_layout_page_width_max) .' }</style>' . "\n";
      break;

    case 'right':
      $styles .= '<style type="text/css">#page_margins { margin-left: auto; margin-right: 0; width: '.theme_get_setting('yaml_layout_page_width') .'; min-width: '. check_plain($yaml_layout_page_width_min) .'; max-width: '. check_plain($yaml_layout_page_width_max) .' }</style>' . "\n";
      break;

    case 'center':
      if ($yaml_layout_page_width_min != '740px' || $yaml_layout_page_width_max != '80em') {
        $styles .= '<style type="text/css">#page_margins { width: '.theme_get_setting('yaml_layout_page_width') .'; min-width: '. check_plain($yaml_layout_page_width_min) .'; max-width: '. check_plain($yaml_layout_page_width_max) .' }</style>' . "\n";
      }
      break;
  }
  return $styles;
}

function _yaml_get_css_ie_themesettings($column_order = '') {
  $styles_ie = '';
  $yaml_layout_page_width_col1 = theme_get_setting('yaml_layout_page_width_col1');
  $yaml_layout_page_width_col3 = theme_get_setting('yaml_layout_page_width_col3');

  // Calculate hacked values for IE.
  $yaml_layout_page_width_col1_ie = '24%';
  if (preg_match('/^(\d{1,5}[.,]?\d{1,3}?)(px|em|%)$/i', $yaml_layout_page_width_col1)) {
    $yaml_layout_page_width_col1_ie = preg_replace('/^(\d{1,5}[.,]?\d{1,3}?)(px|em|%)$/ei', "''. (('$2' == 'px') ? ($1 - 3) : ($1 - 1)) .'$2'", $yaml_layout_page_width_col1);
  }
  $yaml_layout_page_width_col3_ie = '24%';
  if (preg_match('/^(\d{1,5}[.,]?\d{1,3}?)(px|em|%)$/i', $yaml_layout_page_width_col3)) {
    $yaml_layout_page_width_col3_ie = preg_replace('/^(\d{1,5}[.,]?\d{1,3}?)(px|em|%)$/ei', "''. (('$2' == 'px') ? ($1 - 3) : ($1 - 1)) .'$2'", $yaml_layout_page_width_col3);
  }

  switch ($column_order) {
    case '132':
      if ($yaml_layout_page_width_col1 != '25%' || $yaml_layout_page_width_col3 != '25%') {
        $styles_ie .= '* html #col3 { margin-left: '. $yaml_layout_page_width_col1_ie .'; margin-right: '. $yaml_layout_page_width_col3_ie .' }';
      }
      break;

    case '13':
      if ($yaml_layout_page_width_col1 != '25%') {
        $styles_ie .= '* html #col3 { margin-left: '. $yaml_layout_page_width_col1_ie .'; }';
      }
      break;

    case '31':
      if ($yaml_layout_page_width_col1 != '25%') {
        $styles_ie .= '* html #col3 { margin-right: '. $yaml_layout_page_width_col1_ie .'; }';
      }
      break;
  }
  
  return $styles_ie;
}

function _yaml_get_css_ie6_themesettings($column_order = '', $base_theme_directory = '') {
  $styles_ie6 = '';

  // Add some IE6 CSS hacks.
  if (theme_get_setting('yaml_msie_hack_pngfix') == 1) {
    $styles_ie6 .= 'img, .pngtrans { behavior: url('. base_path() . $base_theme_directory .'/images/pngfix/iepngfix.htc) }';
  }

  // See http://www.yaml.de/en/documentation/practice/minimum-maximum-widths.html
  if (theme_get_setting('yaml_layout_page_width') == 'auto') {
    if (theme_get_setting('yaml_msie_hack_minmaxwidth') == 1) {
      // Simulate min-/max-width for IE <=6.
      $yaml_layout_page_width_min = theme_get_setting('yaml_layout_page_width_min');
      $yaml_layout_page_width_max = theme_get_setting('yaml_layout_page_width_max');
      $styles_ie6 .= '* html #page_margins { width: '. $yaml_layout_page_width_max .'; width: expression((document.documentElement && document.documentElement.clientHeight) ? ((document.documentElement.clientWidth < '. preg_replace('/[\D]+/', '', $yaml_layout_page_width_min) .') ? "'. $yaml_layout_page_width_min .'" : ((document.documentElement.clientWidth > (80 * 16 * (parseInt(this.parentNode.currentStyle.fontSize) / 100))) ? "'. $yaml_layout_page_width_max .'" : "auto" )) : ((document.body.clientWidth < '. preg_replace('/[\D]+/', '', $yaml_layout_page_width_min) .') ? "'. $yaml_layout_page_width_min .'" : ((document.body.clientWidth > (80 * 16 * (parseInt(this.parentNode.currentStyle.fontSize) / 100))) ? "'. $yaml_layout_page_width_max .'" : "auto" )));';
    }
    else {
      // IE <=6 does not support min-/max-width what results hereby in the configured fixed max-width.
      $styles_ie6 .= '* html #page_margins { width: '. theme_get_setting('yaml_layout_page_width_max') .' }';
    }
  }
  return $styles_ie6;
}